/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

### File Specific:
   main-programmer: David Hasenfratz
   co-programmer:
*/



/* this is for debug output. It just says, that all calls to PRINT() belong to the DEBUG_MODULE_MEDIA module
   For more information refere to https://www.orxonox.net/cgi-bin/trac.cgi/wiki/DebugOutput
*/
#define DEBUG_MODULE_MEDIA


/* include your own header */
#include "movie_player.h"

/* header for debug output */
#include "debug.h"


/**
 * Default constructor
 */
MoviePlayer::MoviePlayer(const char* filename)
{
  media_container = new MediaContainer(filename);

  this->init();
}

MoviePlayer::MoviePlayer()
{
  media_container = new MediaContainer();

  this->init();
}

/**
 * Default destructor
 */
MoviePlayer::~MoviePlayer()
{
  delete media_container;
}

void MoviePlayer::init()
{
  status = STOP;

  tex = new Texture();
  material = new Material;

  material->setDiffuseMap("maps/radialTransparency.png");

  model = new PrimitiveModel(PRIM_PLANE, 10.0);

  LightManager* lightMan = LightManager::getInstance();
  lightMan->setAmbientColor(.1,.1,.1);
  (new Light())->setAbsCoor(5.0, 10.0, 40.0);
  (new Light())->setAbsCoor(-10, -20, -100);
}

void MoviePlayer::loadMovie(const char* filename)
{
  media_container->loadMedia(filename);
}

void MoviePlayer::printInformation()
{
  media_container->printMediaInformation();
}

void MoviePlayer::start(unsigned int start_frame)
{
  status = PLAY;
}

void MoviePlayer::resume()
{
  status = PLAY;
}

void MoviePlayer::pause()
{
  status = PAUSE;
}

void MoviePlayer::stop()
{
  status = STOP;
}

void MoviePlayer::tick(float time)
{
  surface = media_container->getNextFrame();

  if(surface == NULL)
    texture = NULL;
  else
  {
    bool hasAlpha;
    SDL_Surface* newSurf = tex->prepareSurface(surface, hasAlpha);
    if (newSurf != NULL)
      texture = Texture::loadTexToGL(newSurf);
    else
      texture = NULL;
  }
}

const void MoviePlayer::draw()
{
  material->select();
  glBindTexture(GL_TEXTURE_2D, texture);
  model->draw();

  LightManager::getInstance()->draw();
}

void MoviePlayer::setSpeed(float speed)
{

}

float MoviePlayer::getSpeed()
{
  return speed;
}

const MP_STATUS MoviePlayer::getStatus()
{
  return status;
}
