/*!
 * @file movie_player.h
  *  Manages the media files

*/

#ifndef _MOVIE_PLAYER
#define _MOVIE_PLAYER

#include "glincl.h"
#include "sdlincl.h"

#include "media_container.h"
#include "light.h"
#include "texture.h"
#include "material.h"
#include "primitive_model.h"

/* include base_object.h since all classes are derived from this one */
#include "base_object.h"

/* using namespace std is default, this needs to be here */
using namespace std;

class MediaContainer;
class Model;
class Material;
class Texture;

/* The state of the MoviePlayer */
typedef enum MP_STATUS {
  PLAY,
	PAUSE,
	STOP
};

class MoviePlayer : public BaseObject
{

private:

  MediaContainer* media_container;
  Model* model;
  Material* material;
  Texture* tex;

  SDL_Surface* surface;
  GLuint texture;

  MP_STATUS status;	
  float speed;  

public:

  MoviePlayer(const char* filename);
  MoviePlayer();
  ~MoviePlayer();

  void init();
  void loadMovie(const char* filename);

	void start(unsigned int start_frame);
	void resume();
	void pause();
	void stop();

	void tick(float time);
	const void draw();

	void setSpeed(float speed);
	float getSpeed();
	const MP_STATUS getStatus();
  void printInformation();

};



#endif /* _MOVIE_PLAYER */
